@@ -5,24 +5,11 @@
 import ctypes
 import re
 import numpy as np
-
+from .conversions import list_to_array, array_to_list
 # Regex pattern to determine if c-type is a primative or array
 isArray = re.compile(r"<class '.*\.LP_(c_.*)'>")
 
 
-def array_to_list(input_array, size):
-    """ converts ctypes array to Python list """
-    return [input_array[i] for i in range(size)]
-
-
-def list_to_array(floats, type):
-    """ convert Python list to ctypes array """
-    if floats is None:
-        return None
-    data_length_type = type * len(floats)
-    return ctypes.cast(data_length_type(*floats), ctypes.POINTER(type))
-
-
 def update_boundary_mask(input_list, bad):
     """ update boundary mask for new invalid entries that were replaced """
     mask = []
